@@ -1,3 +1,4 @@
-from .aspect import logger, log, exception_logger, timer
+from .aspect import log, timer
 from .elements import ScreenElement, InputElement, SectionElement, LabelElement, SelectElement, CheckBoxElement
+from .logger import logger
 from .utility import get_methods_and_properties, get_all_methods_and_properties
