@@ -262,7 +262,7 @@ class TableElement(ScreenElement):
 
     class TableRowModel(object):
         """
-        class RowModel(TableRowModel):
+        class RowModel(TableElement.TableRowModel):
 
         def __init__(self, container):
             super().__init__(container)
